
#===========================================================================
# working with density 
# http://sedac.ciesin.columbia.edu/data/set/grump-v1-population-density/data-download
# user: pgobbi, pw:BsAs2013

pop90 <- raster('grump\\gluds90ag.asc',crs='gluds90ag.prj')
# cropping to reduce size of raster
poptp90 <- crop(pop90,  extent(-90,141,-36,38))
pop90 <- poptp90
rm(poptp90) 
pop90[pop90==-9999] <- NA  
# this is needed. David checked.


# GDP from satellite data on light
# data can be downloaded from http://ngdc.noaa.gov/eog/dmsp/download_gdp.html
gdp <- raster('light-satellite\\GDP_grid_flt.tif')

#data from Marc Klemp
gdp_marc <- raster('light-satellite\\AvgLight19922013.tif')

#this is to make a new raster with the same projection as pop90
gdpcr <- projectRaster(gdp, pop90, method="bilinear", alignOnly=FALSE, over=FALSE) 
gdpcr_marc <- projectRaster(gdp_marc, pop90, method="bilinear", alignOnly=FALSE, over=FALSE) 

# we also download gas flaring borders come from NOAA's "Global Gas Flaring Estimates" (http://ngdc.noaa.gov/eog/interest/gas_flares_countries_shapefiles.html) - more information about it can be found here: http://ngdc.noaa.gov/eog/interest/gas_flares.html.
flares <- shapefile('light-satellite\\flares.shp')
#when there are flares, we set the cell to 1 and the gdp to NA
flaresraster <- rasterize(flares,gdpcr_marc)
flaresraster[!is.na(flaresraster)] <- 1
gdpcr2_marc <- overlay(gdpcr_marc, flaresraster, fun=function(x,y){(ifelse(!is.na(y) & y==1,NA,x))} )


#aggregate stuff
pop90agg <- aggregate(pop90, fact=40, fun=mean,na.rm=TRUE)
gdpcragg <- aggregate(gdpcr, fact=40, fun=mean,na.rm=TRUE)
gdpcragg_marc <- aggregate(gdpcr2_marc, fact=40, fun=mean,na.rm=TRUE)

#construct raster of gdp per capita
gdp_cap <- overlay(gdpcragg, pop90agg, fun=function(x,y){(ifelse(!is.na(y) & y>0.1,x/y,NA))} )
gdp_cap_marc <- overlay(gdpcragg_marc, pop90agg, fun=function(x,y){(ifelse(!is.na(y) & y>0.1,x/y,NA))} )


# ======================================================================================================================
# cluster data import

fieldsc <- c("DHSCC","DHSCLUST","LONGNUM","LATNUM","URBAN_RURA","SOURCE") #vector of fields we want from clusters

# Geographic datasets
cl_gn <- read.dbf("dhs-gps\\GNGE42FL.dbf") #  gn: Guinea
cl_gn <- cl_gn[,fieldsc]
cl_ci <- read.dbf("dhs-gps\\CIGE3BFL.dbf") #  ci: Cote d'Ivoire
cl_ci <- cl_ci[,fieldsc]
cl_bf <- read.dbf("dhs-gps\\BFGE32FL.dbf") #  bf: Burkina Faso
cl_bf <- cl_bf[,fieldsc]
cl_bj <- read.dbf("dhs-gps\\BJGE42FL.dbf") #  bj: Benin
cl_bj <- cl_bj[,fieldsc]
cl_ng <- read.dbf("dhs-gps\\NGGE4BFL.dbf") #  ng: Nigeria
cl_ng <- cl_ng[,fieldsc]
cl_cm <- read.dbf("dhs-gps\\CMGE42FL.dbf") #  cm: Cameroon
cl_cm <- cl_cm[,fieldsc]
cl_ke <- read.dbf("dhs-gps\\KEGE43FL.dbf") #  ke: Kenya
cl_ke <- cl_ke[,fieldsc]
cl_ni <- read.dbf("dhs-gps\\NIGE32FL.dbf") #  ni: Niger
cl_ni <- cl_ni[,fieldsc]
cl_tz <- read.dbf("dhs-gps\\TZGE43FL.dbf") #  tz: Tanzania
cl_tz <- cl_tz[,fieldsc]
cl_gh <- read.dbf("dhs-gps\\GHGE42FL.dbf") #  gh: Ghana
cl_gh <- cl_gh[,fieldsc]
#we do not take Angola because type of survey is MIS (no marriage data, no age at first birth, no religion)
#cl_ao <- read.dbf("dhs-gps\\AOGE52FL.dbf") #  ao: Angola
#cl_ao <- cl_ao[,fieldsc]
cl_bu <- read.dbf("dhs-gps\\BUGE61FL.dbf") #  bu: Burundi
cl_bu <- cl_bu[,fieldsc]
cl_cf <- read.dbf("dhs-gps\\CFGE33FL.dbf") #  cf: Central African Republic
cl_cf <- cl_cf[,fieldsc]
cl_km <- read.dbf("dhs-gps\\KMGE61FL.dbf") #  km: Comorros
cl_km <- cl_km[,fieldsc]
cl_cd <- read.dbf("dhs-gps\\CDGE52FL.dbf") #  cd: Congo Democratic Republic
cl_cd <- cl_cd[,fieldsc]
cl_eg <- read.dbf("dhs-gps\\EGGE42FL.dbf") #  et: Egypt
cl_eg <- cl_eg[,fieldsc]
cl_et <- read.dbf("dhs-gps\\ETGE42FL.dbf") #  et: Ethiopia
cl_et <- cl_et[,fieldsc]
cl_ga <- read.dbf("dhs-gps\\GAGE61FL.dbf") #  ga: Gabon
cl_ga <- cl_ga[,fieldsc]
cl_ls <- read.dbf("dhs-gps\\LSGE42FL.dbf") #  ls: Lesotho
cl_ls <- cl_ls[,fieldsc]
cl_lb <- read.dbf("dhs-gps\\LBGE52FL.dbf") #  lb: Liberia
cl_lb <- cl_lb[,fieldsc]
cl_ma <- read.dbf("dhs-gps\\MAGE43FL.dbf") #  ma: Morocco
cl_ma <- cl_ma[,fieldsc]
cl_md <- read.dbf("dhs-gps\\MDGE32FL.dbf") #  md: Madagascar
cl_md <- cl_md[,fieldsc]
cl_mw <- read.dbf("dhs-gps\\MWGE43FL.dbf") #  mw: Malawi
cl_mw <- cl_mw[,fieldsc]
cl_ml <- read.dbf("dhs-gps\\MLGE42FL.dbf") #  ml: Mali
cl_ml <- cl_ml[,fieldsc]
cl_mz <- read.dbf("dhs-gps\\MZGE61FL.dbf") #  mz: Mozambique
cl_mz <- cl_mz[,fieldsc]
cl_nm <- read.dbf("dhs-gps\\NMGE42FL.dbf") #  nm: Namibia
cl_nm <- cl_nm[,fieldsc]
cl_tg <- read.dbf("dhs-gps\\TGGE32FL.dbf") #  tg: Togo
cl_tg <- cl_tg[,fieldsc]
cl_rw <- read.dbf("dhs-gps\\RWGE54FL.dbf") #  rw: Rwanda
cl_rw <- cl_rw[,fieldsc]
cl_sn <- read.dbf("dhs-gps\\SNGE4BFL.dbf") #  sn: Senegal
cl_sn <- cl_sn[,fieldsc]
cl_sl <- read.dbf("dhs-gps\\SLGE53FL.dbf") #  sl: Sierra Leone
cl_sl <- cl_sl[,fieldsc]
cl_sz <- read.dbf("dhs-gps\\SZGE53FL.dbf") #  sz: Swaziland
cl_sz <- cl_sz[,fieldsc]
cl_ug <- read.dbf("dhs-gps\\UGGE43FL.dbf") #  ug: Uganda
cl_ug <- cl_ug[,fieldsc]
cl_zm <- read.dbf("dhs-gps\\ZMGE52FL.dbf") #  zm: Zambia
cl_zm <- cl_zm[,fieldsc]
cl_zw <- read.dbf("dhs-gps\\ZWGE42FL.dbf") #  zw: Zimbabwe
cl_zw <- cl_zw[,fieldsc]
cl_bd <- read.dbf("dhs-gps\\BDGE42FL.dbf") #  bd: Bangladesh
cl_bd <- cl_bd[,fieldsc]
cl_kh <- read.dbf("dhs-gps\\KHGE43FL.dbf") #  kh: Cambodia
cl_kh <- cl_kh[,fieldsc]
cl_id <- read.dbf("dhs-gps\\IDGE43FL.dbf") #  id: Indonesia
cl_id <- cl_id[,fieldsc]
cl_np <- read.dbf("dhs-gps\\NPGE42FL.dbf") #  np: Nepal
cl_np <- cl_np[,fieldsc]
cl_pk <- read.dbf("dhs-gps\\PKGE51FL.dbf") #  pk: Pakistan
cl_pk <- cl_pk[,fieldsc]
cl_ph <- read.dbf("dhs-gps\\PHGE43FL.dbf") #  ph: Philippines
cl_ph <- cl_ph[,fieldsc]
cl_bo <- read.dbf("dhs-gps\\BOGE53FL.dbf") #  bo: Bolivia
cl_bo <- cl_bo[,fieldsc]
cl_co <- read.dbf("dhs-gps\\COGE61FL.dbf") #  co: Colombia
cl_co <- cl_co[,fieldsc]
cl_hn <- read.dbf("dhs-gps\\HNGE61FL.dbf") #  hn: Honduras
cl_hn <- cl_hn[,fieldsc]
cl_pe <- read.dbf("dhs-gps\\PEGE44FL.dbf") #  pe: Peru
cl_pe <- cl_pe[,fieldsc]
cl_jo <- read.dbf("dhs-gps\\JOGE43FL.dbf") #  jo: Jordan
cl_jo <- cl_jo[,fieldsc]

#create the list of data frames to be merged
cllist <- list(cl_gn,cl_ci,cl_bf,cl_bj,cl_ng,cl_cm,cl_ke,cl_ni,cl_tz,cl_gh,
#cl_ao,
   cl_bu,cl_cf,cl_km,cl_cd,cl_et,cl_eg,cl_ga,cl_ls,cl_lb,cl_ma,cl_md,cl_mw,cl_ml,
   cl_mz,cl_nm,cl_tg,cl_rw,cl_sn,cl_sl,cl_sz,cl_ug,cl_zm,cl_zw,cl_bd,cl_kh,cl_id,
   cl_np,cl_pk,cl_ph,cl_bo,cl_co,cl_hn,cl_pe,cl_jo)


#concatenate them with the rbindlist command of the data.table package
cl <- as.data.frame(rbindlist(cllist))

#remove temporary files
rm(cllist)



# ======================================================================================================================
# Prepare clusters data
# Variable of interest
# DHSCLUST Cluster number
# LATNUM Latitude
# LONGNUM Longitude
# SOURCE Source of coordinates (MIS indicates that coordinates are missing)

# See ?as.prevR for the list of variables required to create a prevR object

# here to we identify the cluster by concatenating the country code and the cluster number
cl$id <-  paste(cl$DHSCC,cl$DHSCLUST,sep="-")

cl$x <- cl$LONGNUM
cl$y <- cl$LATNUM

#dummy for urban and rural
cl$urban <- ifelse(cl$URBAN_RURA =="U", 1, 0)


#dummy for countries
cl$GN <- ifelse(cl$DHSCC =="GN", 1, 0)
cl$CI <- ifelse(cl$DHSCC =="CI", 1, 0)
cl$BF <- ifelse(cl$DHSCC =="BF", 1, 0)
cl$BJ <- ifelse(cl$DHSCC =="BJ", 1, 0)
cl$NG <- ifelse(cl$DHSCC =="NG", 1, 0)
cl$CM <- ifelse(cl$DHSCC =="CM", 1, 0)
cl$KE <- ifelse(cl$DHSCC =="KE", 1, 0)
cl$NI <- ifelse(cl$DHSCC =="NI", 1, 0)
cl$TZ <- ifelse(cl$DHSCC =="TZ", 1, 0)
cl$GH <- ifelse(cl$DHSCC =="GH", 1, 0)
#cl$AO <- ifelse(cl$DHSCC =="AO", 1, 0)
cl$BU <- ifelse(cl$DHSCC =="BU", 1, 0)
cl$CF <- ifelse(cl$DHSCC =="CF", 1, 0)
cl$KM <- ifelse(cl$DHSCC =="KM", 1, 0)
cl$CD <- ifelse(cl$DHSCC =="CD", 1, 0)
cl$EG <- ifelse(cl$DHSCC =="EG", 1, 0)
cl$ET <- ifelse(cl$DHSCC =="ET", 1, 0)
cl$GA <- ifelse(cl$DHSCC =="GA", 1, 0)
cl$LS <- ifelse(cl$DHSCC =="LS", 1, 0)
cl$LB <- ifelse(cl$DHSCC =="LB", 1, 0)
cl$MA <- ifelse(cl$DHSCC =="MA", 1, 0)
cl$MD <- ifelse(cl$DHSCC =="MD", 1, 0)
cl$MW <- ifelse(cl$DHSCC =="MW", 1, 0)
cl$ML <- ifelse(cl$DHSCC =="ML", 1, 0)
cl$MZ <- ifelse(cl$DHSCC =="MZ", 1, 0)
cl$NM <- ifelse(cl$DHSCC =="NM", 1, 0)
cl$TG <- ifelse(cl$DHSCC =="TG", 1, 0)
cl$RW <- ifelse(cl$DHSCC =="RW", 1, 0)
cl$SN <- ifelse(cl$DHSCC =="SN", 1, 0)
cl$SL <- ifelse(cl$DHSCC =="SL", 1, 0)
cl$SZ <- ifelse(cl$DHSCC =="SZ", 1, 0)
cl$UG <- ifelse(cl$DHSCC =="UG", 1, 0)
cl$ZM <- ifelse(cl$DHSCC =="ZM", 1, 0)
cl$ZW <- ifelse(cl$DHSCC =="ZW", 1, 0)
cl$BD <- ifelse(cl$DHSCC =="BD", 1, 0)
cl$KH <- ifelse(cl$DHSCC =="KH", 1, 0)
cl$ID <- ifelse(cl$DHSCC =="ID", 1, 0)
cl$NP <- ifelse(cl$DHSCC =="NP", 1, 0)
cl$PK <- ifelse(cl$DHSCC =="PK", 1, 0)
cl$PH <- ifelse(cl$DHSCC =="PH", 1, 0)
cl$BO <- ifelse(cl$DHSCC =="BO", 1, 0)
cl$CO <- ifelse(cl$DHSCC =="CO", 1, 0)
cl$HN <- ifelse(cl$DHSCC =="HN", 1, 0)
cl$PE <- ifelse(cl$DHSCC =="PE", 1, 0)
cl$JO <- ifelse(cl$DHSCC =="JO", 1, 0)


#country variable
cl$country <- 0
cl$country <- ifelse(cl$GN==1, 1, cl$country)
cl$country <- ifelse(cl$CI==1, 2, cl$country)
cl$country <- ifelse(cl$BF==1, 3, cl$country)
cl$country <- ifelse(cl$BJ==1, 4, cl$country)
cl$country <- ifelse(cl$NG==1, 5, cl$country)
cl$country <- ifelse(cl$CM==1, 6, cl$country)
cl$country <- ifelse(cl$KE==1, 7, cl$country)
cl$country <- ifelse(cl$NI==1, 8, cl$country)
cl$country <- ifelse(cl$TZ==1, 9, cl$country)
cl$country <- ifelse(cl$GH==1, 10, cl$country)
cl$country <- ifelse(cl$BU==1, 11, cl$country)
cl$country <- ifelse(cl$CF==1, 12, cl$country)
cl$country <- ifelse(cl$KM==1, 13, cl$country)
cl$country <- ifelse(cl$CD==1, 14, cl$country)
cl$country <- ifelse(cl$EG==1, 15, cl$country)
cl$country <- ifelse(cl$ET==1, 16, cl$country)
cl$country <- ifelse(cl$GA==1, 17, cl$country)
cl$country <- ifelse(cl$LS==1, 18, cl$country)
cl$country <- ifelse(cl$LB==1, 19, cl$country)
cl$country <- ifelse(cl$MA==1, 20, cl$country)
cl$country <- ifelse(cl$MD==1, 21, cl$country)
cl$country <- ifelse(cl$MW==1, 22, cl$country)
cl$country <- ifelse(cl$ML==1, 23, cl$country)
cl$country <- ifelse(cl$MZ==1, 24, cl$country)
cl$country <- ifelse(cl$NM==1, 25, cl$country)
cl$country <- ifelse(cl$TG==1, 26, cl$country)
cl$country <- ifelse(cl$RW==1, 27, cl$country)
cl$country <- ifelse(cl$SN==1, 28, cl$country)
cl$country <- ifelse(cl$SL==1, 29, cl$country)
cl$country <- ifelse(cl$SZ==1, 30, cl$country)
cl$country <- ifelse(cl$UG==1, 31, cl$country)
cl$country <- ifelse(cl$ZM==1, 32, cl$country)
cl$country <- ifelse(cl$ZW==1, 33, cl$country)
cl$country <- ifelse(cl$BD==1, 34, cl$country)
cl$country <- ifelse(cl$KH==1, 35, cl$country)
cl$country <- ifelse(cl$ID==1, 36, cl$country)
cl$country <- ifelse(cl$NP==1, 37, cl$country)
cl$country <- ifelse(cl$PK==1, 38, cl$country)
cl$country <- ifelse(cl$PH==1, 39, cl$country)
cl$country <- ifelse(cl$BO==1, 40, cl$country)
cl$country <- ifelse(cl$CO==1, 41, cl$country)
cl$country <- ifelse(cl$HN==1, 42, cl$country)
cl$country <- ifelse(cl$PE==1, 43, cl$country)
cl$country <- ifelse(cl$JO==1, 44, cl$country)

#to check there are not 0 remaining:
table(cl$country)


# indicative variable for whether the country is among the leas developed economies according to ECOSOC

cl$country_poor <- ifelse(cl$BJ==1 | cl$BF==1 | cl$BU==1 | cl$CF==1 | cl$KM==1 | cl$CD==1 | cl$ET==1 | 
				  cl$GN==1 | cl$LS==1 | cl$LB==1 | cl$MD==1 | cl$MW==1 | cl$ML==1 | cl$MZ==1 |
				  cl$NI==1 | cl$RW==1 | cl$SN==1 | cl$SL==1 | cl$TZ==1 | cl$TG==1 | cl$UG==1 |
				  cl$ZM==1 | cl$BD==1 | cl$KH==1 | cl$NP==1 ,1,0				  )


#==========================================
# here we generate a variable continent
# continent= 1 for africa; 2 for america; 3 for asia- south east and 4 for mena  countries

cl$continent <- ifelse( 
				#cl$AO==1 | 
				cl$BJ==1 | cl$BF==1 | cl$BU==1 | cl$CM==1 | cl$CF==1 | cl$KM==1 |
				 cl$CD==1 | cl$CI==1 | cl$ET==1 | cl$GA==1 | cl$GH==1 | cl$GN==1 | cl$KE==1 |
				 cl$LS==1 | cl$LB==1 | cl$MD==1 | cl$MW==1 | cl$ML==1 | cl$MZ==1 |
				 cl$NM==1 | cl$NI==1 | cl$NG==1 | cl$RW==1 | cl$SN==1 | cl$SL==1 | 
				 cl$SZ==1 | cl$TG==1 | cl$TZ==1 | cl$UG==1 | cl$ZM==1 | cl$ZW==1,1,
                     ifelse( cl$BO==1 | cl$CO==1 | cl$HN==1 | cl$PE==1,2,
                     ifelse( cl$BD==1 | cl$KH==1 | cl$ID==1 | cl$NP==1 | cl$PK==1 | cl$PH==1,3,
                     ifelse( cl$MA==1 | cl$EG==1 | cl$JO==1,4,0))))

summary(cl$continent) # min should be 1 




# We will keep only clusters for whose coordinates have been collected
cl <- cl[cl$SOURCE!="MIS",]

# We also eliminate those which are at the intersection of Greenwich and Equator by mistake
cl <- cl[cl$x!=0 & cl$y!=0,]


# ==================================================================================
# calories you can get from the land
# data can be downloaded from http://www.econ.brown.edu/fac/Oded_Galor/data.html

calories_post1500 <- raster('soil\\post1500OptCalories.tif')
calories_pre1500 <- raster('soil\\pre1500OptCalories.tif')

#extract calories from raster
cl$calories <- extract(calories_post1500,cbind(cl$x,cl$y))
cl$calories_pre1500 <- extract(calories_pre1500,cbind(cl$x,cl$y))
summary(cl$calories)
summary(cl$calories_pre1500)

#there are 2 NAs, what should we do???
cl$calories <- ifelse(is.na(cl$calories),extract(calories_post1500,cbind(cl$x,cl$y),buffer=10000,fun=mean),cl$calories)
cl$calories_pre1500 <- ifelse(is.na(cl$calories_pre1500),extract(calories_pre1500,cbind(cl$x,cl$y),buffer=10000,fun=mean),cl$calories_pre1500)

#normalize calories
cl$calories_norm <- cl$calories/1000
cl$calories_pre1500_norm <- cl$calories_pre1500/1000

# ==================================================================================

#extract density from raster
# buffer: radius of a buffer around the point, in meters.
# fun: function to summarize the values

# we set the buffer to 2km in urban clusters and to 5km in rural clusters, according to the dispacement in DHS 
cl$dens90 <- ifelse(cl$urban==1,extract(pop90,cbind(cl$x,cl$y),buffer=2000,fun=mean),extract(pop90,cbind(cl$x,cl$y),buffer=5000,fun=mean))
summary(cl$dens90)

# there are 12 NAs remaining: observations 10860 and 10928 in Uganda in Lake Victoria, one in Indonesia, the rest in Colombia. 
# Uganda: 
cl$dens90 <- ifelse(is.na(cl$dens90) & cl$DHSCC=="UG",extract(pop90,cbind(cl$x,cl$y),buffer=13000,fun=mean),cl$dens90)
cl$dens90 <- ifelse(is.na(cl$dens90) & cl$DHSCC=="UG",extract(pop90,cbind(cl$x,cl$y),buffer=33000,fun=mean),cl$dens90)
# Indonesia, Palau Belitung:
cl$dens90 <- ifelse(is.na(cl$dens90) & cl$DHSCC=="ID",extract(pop90,cbind(cl$x,cl$y),buffer=6000,fun=mean),cl$dens90)

summary(cl$dens90)
min(cl$dens90)

# treat 0 densities. There are 6 observations in this case, all in Egypt
cl$dens90 <- ifelse(cl$dens90==0,extract(pop90,cbind(cl$x,cl$y),buffer=20000,fun=mean),cl$dens90)
min(cl$dens90)

#summary: we compute mean density in a circle around the coordinates with a radius of 2km in urban areas and 5km in rural areas 
# if the obtained density is NA or 0, we enlarge the radius. 



#builds a list of clusters that will be used to eliminate households and women in
# cluster absent from the data (i.e. with no GPS coordinates) 
listc <- unique(cl$id)



# extract gdp per capital from raster
cl$gdp_capita <-extract(gdp_cap,cbind(cl$x,cl$y),buffer=50000,fun=mean)
summary(cl$gdp_capita)

cl$gdp_capita_marc <-extract(gdp_cap_marc,cbind(cl$x,cl$y),buffer=50000,fun=mean)
summary(cl$gdp_capita_marc)





# ================== distance to unesco sites

sites <- read.dta("unesco.dta")

sites_col <- sites[sites$col==1,]
sites_nocol <- sites[sites$col==0,]

sites$liens <- 0
sites_col$liens <- 0
sites_nocol$liens <- 0

for (i in 1:nrow(cl)){
cl$dist_site[i] <- 100000000000
cl$dist_site_col[i] <- 100000000000
cl$dist_site_nocol[i] <- 100000000000

for (j in 1:nrow(sites)){
temp<- pointDistance(c(cl$x[i], cl$y[i]), c(sites$x[j], sites$y[j]), lonlat=TRUE)
if (temp<cl$dist_site[i]){cl$dist_site[i]<-temp
pointeur=j}
}
sites$liens[pointeur] <- sites$liens[pointeur]+1

for (j in 1:nrow(sites_col)){
temp<- pointDistance(c(cl$x[i], cl$y[i]), c(sites_col$x[j], sites_col$y[j]), lonlat=TRUE)
if (temp<cl$dist_site_col[i]){cl$dist_site_col[i]<-temp
pointeur=j}
}
sites_col$liens[pointeur] <- sites_col$liens[pointeur]+1

for (j in 1:nrow(sites_nocol)){
temp<- pointDistance(c(cl$x[i], cl$y[i]), c(sites_nocol$x[j], sites_nocol$y[j]), lonlat=TRUE)
if (temp<cl$dist_site_nocol[i]){cl$dist_site_nocol[i]<-temp
pointeur=j}
}
sites_nocol$liens[pointeur] <- sites_nocol$liens[pointeur]+1
}


write.dbf(sites,"sites-links.dbf")
write.dbf(sites_col,"sites-col-links.dbf")
write.dbf(sites_nocol,"sites-nocol-links.dbf")


cl$dist_site<-cl$dist_site/111120
cl$dist_site_col<-cl$dist_site_col/111120
cl$dist_site_nocol<-cl$dist_site_nocol/111120


#==========================================
# Household Recode loaded from Stata format
# Relevant field
# hv000: Alphabetic country code to identify the survey from which the data were collected. 
# hv001: Cluster number is the number identifying the sample point as used during the field work
# hv005: Household weight
# hv270: the DHS wealth index. This variable is not present in half our African countries
# hv206: Household has electricity.
# hv209: Household has a refrigerator. Ethiopia (and maybe others) does not have info on this. 

#=================================================================
# Individual Recode loaded from Stata format
# Select relevant fields
# v000 Alphabetic country code to identify the survey from which the data were collected. 
# v001 Cluster number is the number identifying the sample point as used during the field work
# v002 Household number is the number identifying the household in which the respondent was interviewed
# v003 Respondent's line number
# v005 Sample weight is an 8 digit variable with 6 implied decimal places.
#        To use the sample weight divide it by 1000000 before applying the weighting factor. 
# v008 Century month code of date of interview 
# v011 Century month code (cmc) of date of birth of the respondent
# v012 Current age in completed years 
# v024 Region 
# v104 years lived in place of residence
# v133 Education in single years 
# v134 De facto place of residence is the type of place in which the respondent was interviewed
#           (countryside, town, small city, "capital, large city"  
# v149 Educational achievement recodes the education of the respondent into the following categories:
#        None, incomplete primary, complete primary, incomplete secondary, complete secondary, higher education.
# v201 Total number of children ever born.
# v211 date of first birth (cmc)
# v212 Age of respondant at first birth
# v218 Total number of living children
# v501 current marital status 
# v502 currently/formerly/never married
# v509 date of first marriage (cmc)
# v511 age at first marriage  
# v715 Most recent husband or partner's education in single years (BASE: Ever-married women (V501 <> 0))

# v208 births in last 5 years
# v613 ideal number of children

# fields to keep for women and households
fields <- c("v000","v001","v002","v003","v005","v008","v011","v012","v024",
            "v104","v133","v201","v211","v212","v218","v501",
            "v502","v509","v511","v715","v208","v613","islam","christian","hinduism","buddhism","strate")
fieldsh <- c("hv000","hv001","hv005","hv002","hv206","hv209")
# dummies for the ethnicities
fieldet <- c("ethn1","ethn2","ethn3","ethn4","ethn5","ethn6","ethn7","ethn8","ethn9",
"ethn10","ethn11","ethn12","ethn13","ethn14","ethn15","ethn16","ethn17",
"ethn19","ethn20","ethn21","ethn22","ethn23","ethn24","ethn25","ethn26",
"ethn27","ethn28","ethn29","ethn30","ethn31","ethn32","ethn33","ethn34",
"ethn35","ethn36","ethn37","ethn38","ethn39","ethn40","ethn41","ethn42",
"ethn43","ethn44","ethn45","ethn46","ethn47","ethn48","ethn49","ethn50",
"ethn51","ethn52","ethn53","ethn54","ethn55","ethn56","ethn57","ethn58",
"ethn59","ethn60","ethn61","ethn62","ethn63","ethn64","ethn65","ethn66",
"ethn67","ethn68","ethn69","ethn70","ethn71","ethn72","ethn73","ethn74",
"ethn75","ethn76","ethn77","ethn79","ethn80","ethn81","ethn82","ethn83",
"ethn84","ethn85","ethn86","ethn87","ethn89","ethn91","ethn92","ethn93",
"ethn94","ethn95","ethn97","ethn98","ethn99","ethn100","ethn101","ethn102",
"ethn103","ethn104","ethn105","ethn106","ethn107","ethn108","ethn109","ethn110",
"ethn111","ethn112","ethn113","ethn114","ethn115","ethn116","ethn117","ethn118",
"ethn119","ethn120","ethn121","ethn122","ethn123","ethn124","ethn125","ethn126",
"ethn127","ethn128","ethn129","ethn130","ethn131","ethn132","ethn133","ethn134",
"ethn135","ethn136","ethn137","ethn138","ethn139","ethn140","ethn141","ethn142",
"ethn143","ethn144","ethn145","ethn146","ethn147","ethn148","ethn149","ethn150",
"ethn151","ethn152","ethn153","ethn154","ethn155","ethn156","ethn157","ethn158",
"ethn159","ethn160","ethn161","ethn162","ethn163","ethn164","ethn165","ethn166",
"ethn167","ethn168","ethn169","ethn170","ethn171","ethn172","ethn173","ethn174",
"ethn175","ethn176","ethn177","ethn178","ethn180","ethn181","ethn182","ethn183",
"ethn184","ethn185","ethn186","ethn187","ethn188","ethn189","ethn190","ethn191",
"ethn192","ethn193","ethn194","ethn195","ethn196","ethn197","ethn198","ethn199",
"ethn200","ethn201","ethn202","ethn203","ethn204","ethn205","ethn206","ethn207",
"ethn208","ethn209","ethn210","ethn211","ethn212","ethn213","ethn214","ethn215",
"ethn216","ethn217","ethn218","ethn219","ethn220","ethn221","ethn222","ethn223",
"ethn224","ethn225","ethn226","ethn227","ethn228","ethn229","ethn230","ethn231",
"ethn232","ethn233","ethn234","ethn235","ethn236","ethn237","ethn238","ethn239",
"ethn240","ethn241","ethn242")


#How to make a woman------------------------------------------------
makewoman <- function(base1, base2){
#reading data
hh <-read.dta(base1,convert.factors=FALSE)
hh <- hh[,fieldsh]
wom <-read.dta(base2,convert.factors=FALSE) 
wom <- wom[,c(fields,fieldet)]

#building household indentification
hh$household <- paste(substr(hh$hv000,1,2),hh$hv001,hh$hv002,sep="-")
wom$household <- paste(substr(wom$v000,1,2),wom$v001,wom$v002,sep="-")

#building women data
#we identify the cluster by the country code and the cluster number
wom$cluster <- paste(substr(wom$v000,1,2),wom$v001,sep="-")
# Sampling weight (V005/10000, cf. DHS documentation)
wom$weight <- wom$v005/1000000
# Total number of birth, living birth and mortality rate
wom$birth <- wom$v201
wom$living <- wom$v218
wom$mortal <- ifelse(wom$v201>0,(wom$v201-wom$v218)/wom$v201,0)

# controls for regression
wom$age <- wom$v012
wom$age_month <- wom$v008-wom$v011
wom$married <- ifelse(wom$v502==1 | wom$v502==2,1,0)

# age at first birth
wom$agefb <- wom$v212
wom$agemother <- ifelse(wom$birth>0,wom$agefb,wom$age)
wom$mother <- ifelse(wom$birth>0, 1, 0)

# age at first birth in months
wom$agefb_month <- wom$v211-wom$v011
wom$agemother_month <- ifelse(wom$birth>0,wom$agefb_month,wom$age_month)

# age at first marriage
wom$agefm <- wom$v511
wom$agemarried <- ifelse(wom$married==1,wom$agefm,wom$age)

# age at first marriage in months
wom$agefm_month <- wom$v509-wom$v011 
wom$agemarried_month <- ifelse(wom$married==1,wom$agefm_month,wom$age_month)

# interval between first marriage and first birth (this gives the interval in months)
wom$interval <- ifelse(!is.na(wom$v211) & !is.na(wom$v509),wom$v211-wom$v509,NA)

#education
wom$educ <- wom$v133
# We drop the observations with no information on educ or those with educ==99
wom <- wom[wom$educ<30,]
wom <- wom[!is.na(wom$educ),]

#partner's education
wom$educ_sp <- ifelse(!is.na(wom$v715) & wom$v715<=30,wom$v715,NA)

#desired number of children
wom$desired <- ifelse(!is.na(wom$v613) & wom$v613<=30, wom$v613, NA)


# eliminate households with no known cluster
wom <- wom[wom$cluster %in% listc,]

#imputing household data to women
# the household owns a refrigerator, yes or no
hh$refri <- ifelse(hh$hv209<2,hh$hv209,NA)
hh$electr <- ifelse(hh$hv206<2,hh$hv206,NA)
hh$weight <- hh$hv005/1000000
listh <- unique(wom$household)
for (i in listh) {
wom[wom$household==i,"electr"] <- max(hh$electr[hh$household==i])
wom[wom$household==i,"refri"] <- max(hh$refri[hh$household==i])
wom[wom$household==i,"weighth"] <- max(hh$weight[hh$household==i])
# here there is something strange. in some cases hh$refri gives 2 numbers. Hence the max
}
return(wom)
}


wom_gn <- makewoman("dhs-household\\GNHR41FL.dta","tmp\\GNIR41FLm.dta")
wom_ci <- makewoman("dhs-household\\CIHR3AFL.dta","tmp\\CIIR3AFLm.dta")
wom_bf <- makewoman("dhs-household\\BFHR31FL.dta","tmp\\BFIR31FLm.dta")
wom_bj <- makewoman("dhs-household\\BJHR41FL.dta","tmp\\BJIR41FLm.dta")
wom_ng <- makewoman("dhs-household\\NGHR4BFL.dta","tmp\\NGIR4BFLm.dta")
wom_cm <- makewoman("dhs-household\\CMHR44FL.dta","tmp\\CMIR44FLm.dta")
wom_ke <- makewoman("dhs-household\\KEHR42FL.dta","tmp\\KEIR42FLm.dta")
wom_ni <- makewoman("dhs-household\\NIHR31FL.dta","tmp\\NIIR31FLm.dta")
wom_tz <- makewoman("dhs-household\\TZHR41FL.dta","tmp\\TZIR41FLm.dta")
wom_gh <- makewoman("dhs-household\\GHHR41FL.dta","tmp\\GHIR41FLm.dta")
#wom_ao <- makewoman("dhs-household\\AOHR51FL.dta","tmp\\AOIR51FLm.dta")
wom_bu <- makewoman("dhs-household\\BUHR61FL.dta","tmp\\BUIR61FLm.dta")
wom_cf <- makewoman("dhs-household\\CFHR31FL.dta","tmp\\CFIR31FLm.dta")
wom_km <- makewoman("dhs-household\\KMHR61FL.dta","tmp\\KMIR61FLm.dta")
wom_cd <- makewoman("dhs-household\\CDHR50FL.dta","tmp\\cdir50FLm.dta")
wom_eg <- makewoman("dhs-household\\EGHR42FL.dta","tmp\\EGIR42FLm.dta")
wom_et <- makewoman("dhs-household\\ETHR41FL.dta","tmp\\ETIR41FLm.dta")
wom_ga <- makewoman("dhs-household\\GAHR60FL.dta","tmp\\GAIR60FLm.dta")
wom_ls <- makewoman("dhs-household\\LSHR41FL.dta","tmp\\LSIR41FLm.dta")
wom_lb <- makewoman("dhs-household\\LBHR51FL.dta","tmp\\LBIR51FLm.dta")
wom_ma <- makewoman("dhs-household\\MAHR43FL.dta","tmp\\MAIR43FLm.dta")
wom_md <- makewoman("dhs-household\\MDHR31FL.dta","tmp\\MDIR31FLm.dta")
wom_mw <- makewoman("dhs-household\\MWHR41FL.dta","tmp\\MWIR41FLm.dta")
wom_ml <- makewoman("dhs-household\\MLHR41FL.dta","tmp\\MLIR41FLm.dta")
wom_mz <- makewoman("dhs-household\\MZHR62FL.dta","tmp\\MZIR62FLm.dta")
wom_nm <- makewoman("dhs-household\\NMHR41FL.dta","tmp\\NMIR41FLm.dta")
wom_tg <- makewoman("dhs-household\\TGHR31FL.dta","tmp\\TGIR31FLm.dta")
wom_rw <- makewoman("dhs-household\\RWHR53FL.dta","tmp\\RWIR53FLm.dta")
wom_sn <- makewoman("dhs-household\\SNHR4HFL.dta","tmp\\SNIR4HFLm.dta")
wom_sl <- makewoman("dhs-household\\SLHR51FL.dta","tmp\\SLIR51FLm.dta")
wom_sz <- makewoman("dhs-household\\SZHR51FL.dta","tmp\\szir51flm.dta")
wom_ug <- makewoman("dhs-household\\UGHR41FL.dta","tmp\\UGIR41FLm.dta")
wom_zm <- makewoman("dhs-household\\ZMHR51FL.dta","tmp\\ZMIR51FLm.dta")
wom_zw <- makewoman("dhs-household\\ZWHR42FL.dta","tmp\\ZWIR42FLm.dta")
wom_bd <- makewoman("dhs-household\\BDHR41FL.dta","tmp\\BDIR41FLm.dta")
wom_kh <- makewoman("dhs-household\\KHHR42FL.dta","tmp\\KHIR42FLm.dta")
wom_id <- makewoman("dhs-household\\IDHR42FL.dta","tmp\\IDIR42FLm.dta")
wom_np <- makewoman("dhs-household\\NPHR41FL.dta","tmp\\NPIR41FLm.dta")
wom_pk <- makewoman("dhs-household\\pkhr52fl.dta","tmp\\pkir52flm.dta")
wom_ph <- makewoman("dhs-household\\PHHR41FL.dta","tmp\\PHIR41FLm.dta")
wom_bo <- makewoman("dhs-household\\BOHR51FL.dta","tmp\\BOIR51FLm.dta")
wom_co <- makewoman("dhs-household\\COHR61FL.dta","tmp\\COIR61FLm.dta")
wom_hn <- makewoman("dhs-household\\HNHR62FL.dta","tmp\\HNIR62FLm.dta")
wom_pe <- makewoman("dhs-household\\PEHR41FL.dta","tmp\\PEIR41FLm.dta")
wom_jo <- makewoman("dhs-household\\JOHR42FL.dta","tmp\\JOIR42FLm.dta")


#create the list of data frames to be merged
womlist <- list(wom_gn,wom_ci,wom_bf,wom_bj,wom_ng,wom_cm,wom_ke,wom_ni,wom_tz,wom_gh,
#wom_ao,
   wom_bu,wom_cf,wom_cd,wom_km,wom_et,wom_ga,wom_ls,wom_lb,wom_ma,wom_md,wom_mw,wom_ml,
   wom_mz,wom_nm,wom_tg,wom_rw,wom_sn,wom_sl,wom_sz,wom_ug,wom_zm,wom_zw,wom_eg,wom_bd,
   wom_kh,wom_id,wom_np,wom_pk,wom_ph,wom_bo,wom_co,wom_hn,wom_pe,wom_jo)


#concatenate them with the rbindlist command of the data.table package
wom <- as.data.frame(rbindlist(womlist)) 

#remove temporary files
rm(womlist)

# migration
#values of the variable: 2=missing, 1=moved after 14, 0=did not move
wom$migrant1 <- ifelse(wom$v012-wom$v104>14,1,0)
wom$migrant <- ifelse(is.na(wom$v104),2,wom$migrant1)

wom$migrant_yes <-ifelse(wom$migrant==1,1,0)
wom$migrant_na <-ifelse(wom$migrant==2,1,0)

#=====================================================================
# We compute clusters' variable from individual data
# pfor prevR, for each cluster, we need the number of observations (n), the number of births (pos)
# and the sum of observations and birth weights (wn, wpos)

#first create new variables outside the loop (this is supposed to speed up things)
cl[c("n","wn","pos","wpos","age","educ","mortal","marriage","refri","electr","islam","christian","buddhism","hinduism",
     "migrant_yes","migrant_na","region")] <- NA 


# then update them within the loop
for (i in listc) {
                   # we put in temp the women of the cluster i, with the useful variables

  temp <- wom[wom$cluster==i,c("birth","weight","weighth","age","educ","educ_sp","mortal","married","refri","electr","islam",
					 "christian","buddhism","hinduism","migrant_yes","migrant_na","v024")] 

  # variables designed for using prevR
  cl[cl$id==i,"n"] <- nrow(temp)  # nrow returns the number of rows present in x, here the number of women in a cluster
  cl[cl$id==i,"wn"] <- sum(temp$weight) # here we calculate the total weight of the cluster
  cl[cl$id==i,"pos"] <- sum(temp$birth) # we count the number of births
  cl[cl$id==i,"wpos"] <- sum(temp$weight*temp$birth) # we count the weighted number of births

  # variables for the regression
  # Arithmetic functions on missing values yield missing values unless the option  na.rm=TRUE  is used

  cl[cl$id==i,"age"] <- sum(temp$weight*temp$age)/sum(temp$weight) # mean age in the cluster
  cl[cl$id==i,"educ"] <- sum(temp$weight*temp$educ)/sum(temp$weight) # mean educ in the cluster
  cl[cl$id==i,"educ_sp"] <- sum(temp$weight*temp$educ_sp)/sum(temp$weight) # mean educ in the cluster

  cl[cl$id==i,"mortal"] <- sum(temp$weight*temp$mortal)/sum(temp$weight) # mean educ in the cluster
  cl[cl$id==i,"marriage"] <- sum(temp$weight*temp$married)/sum(temp$weight) # marriage rate in the cluster

  cl[cl$id==i,"refri"] <- sum(temp$weighth*temp$refri)/sum(temp$weighth) # refrigerator ownership rate in the cluster
  cl[cl$id==i,"electr"] <- sum(temp$weighth*temp$electr)/sum(temp$weighth) # has electricity rate in the cluster

  cl[cl$id==i,"islam"] <- sum(temp$weight*temp$islam)/sum(temp$weight) # islamic rate in the cluster
  cl[cl$id==i,"christian"] <- sum(temp$weight*temp$christian)/sum(temp$weight) # christianity rate in the cluster
  cl[cl$id==i,"buddhism"] <- sum(temp$weight*temp$buddhism)/sum(temp$weight) # buddhism rate in the cluster
  cl[cl$id==i,"hinduism"] <- sum(temp$weight*temp$hinduism)/sum(temp$weight) # hinduism rate in the cluster

  cl[cl$id==i,"migrant_yes"] <- sum(temp$weight*temp$migrant_yes)/sum(temp$weight)
  cl[cl$id==i,"migrant_na"] <- sum(temp$weight*temp$migrant_na)/sum(temp$weight)

  cl[cl$id==i,"region"] <- sum(temp$weight*temp$v024)/sum(temp$weight)
}


# clusters with stayers only
for (i in listc) {

  temp <- wom[wom$cluster==i & wom$migrant_yes==0 & wom$migrant_na==0,c("birth","weight","weighth","age","educ","educ_sp","mortal","married")] 

  # variables designed for using prevR
  cl[cl$id==i,"n_stayers"] <- nrow(temp)  # nrow returns the number of rows present in x, here the number of women in a cluster
  cl[cl$id==i,"wn_stayers"] <- sum(temp$weight) # here we calculate the total weight of the cluster
  cl[cl$id==i,"pos_stayers"] <- sum(temp$birth) # we count the number of births
  cl[cl$id==i,"wpos_stayers"] <- sum(temp$weight*temp$birth) # we count the weighted number of births

  # variables for the regression
  # Arithmetic functions on missing values yield missing values unless the option  na.rm=TRUE  is used

  cl[cl$id==i,"age_stayers"] <- sum(temp$weight*temp$age)/sum(temp$weight) # mean age in the cluster
  cl[cl$id==i,"educ_stayers"] <- sum(temp$weight*temp$educ)/sum(temp$weight) # mean educ in the cluster

  cl[cl$id==i,"mortal_stayers"] <- sum(temp$weight*temp$mortal)/sum(temp$weight) # mean educ in the cluster
  cl[cl$id==i,"marriage_stayers"] <- sum(temp$weight*temp$married)/sum(temp$weight) # marriage rate in the cluster
}

# clusters with stayers only
for (i in listc) {

  temp <- wom[wom$cluster==i & wom$migrant_yes==0,c("birth","weight","weighth","age","educ","educ_sp","mortal","married")] 

  # variables designed for using prevR
  cl[cl$id==i,"n_nomig"] <- nrow(temp)  # nrow returns the number of rows present in x, here the number of women in a cluster
  cl[cl$id==i,"wn_nomig"] <- sum(temp$weight) # here we calculate the total weight of the cluster
  cl[cl$id==i,"pos_nomig"] <- sum(temp$birth) # we count the number of births
  cl[cl$id==i,"wpos_nomig"] <- sum(temp$weight*temp$birth) # we count the weighted number of births

  # variables for the regression
  # Arithmetic functions on missing values yield missing values unless the option  na.rm=TRUE  is used

  cl[cl$id==i,"age_nomig"] <- sum(temp$weight*temp$age)/sum(temp$weight) # mean age in the cluster
  cl[cl$id==i,"educ_nomig"] <- sum(temp$weight*temp$educ)/sum(temp$weight) # mean educ in the cluster

  cl[cl$id==i,"mortal_nomig"] <- sum(temp$weight*temp$mortal)/sum(temp$weight) # mean educ in the cluster
  cl[cl$id==i,"marriage_nomig"] <- sum(temp$weight*temp$married)/sum(temp$weight) # marriage rate in the cluster
}


# drop NA ages (some clusters populated by zombies and vampires)
# there are no women in 10 clusters: BJ-3,NG-310,GH-306,GA-56,MD-258,MW-3108,NM-53,NM-162,UG-2501,UG-3206)
cl <- cl[!is.na(cl$age),]

# computing the "birth rate"
cl$rate=cl$wpos/cl$wn
summary(cl$rate)

cl$densq90 <-cl$dens90^2
cl$agesq <-cl$age^2
cl$educsq <- cl$educ^2 
cl$urbandens90 <-log(1+cl$dens90)*cl$urban

# check that there are no empty clusters
min(cl$wn)

#region variable
cl$region_id <- cl$country*100+cl$region
table(cl$region_id)
hist(cl$region_id)


# ============================================================================
# preparing for poisson

#dummy for countries
wom$GN <- ifelse(substr(wom$v000,1,2) =="GN", 1, 0)
wom$CI <- ifelse(substr(wom$v000,1,2) =="CI", 1, 0)
wom$BF <- ifelse(substr(wom$v000,1,2) =="BF", 1, 0)
wom$BJ <- ifelse(substr(wom$v000,1,2) =="BJ", 1, 0)
wom$NG <- ifelse(substr(wom$v000,1,2) =="NG", 1, 0)
wom$CM <- ifelse(substr(wom$v000,1,2) =="CM", 1, 0)
wom$KE <- ifelse(substr(wom$v000,1,2) =="KE", 1, 0)
wom$NI <- ifelse(substr(wom$v000,1,2) =="NI", 1, 0)
wom$TZ <- ifelse(substr(wom$v000,1,2) =="TZ", 1, 0)
wom$GH <- ifelse(substr(wom$v000,1,2) =="GH", 1, 0)
#wom$AO <- ifelse(substr(wom$v000,1,2) =="AO", 1, 0)
wom$BU <- ifelse(substr(wom$v000,1,2) =="BU", 1, 0)
wom$CF <- ifelse(substr(wom$v000,1,2) =="CF", 1, 0)
wom$KM <- ifelse(substr(wom$v000,1,2) =="KM", 1, 0)
wom$CD <- ifelse(substr(wom$v000,1,2) =="CD", 1, 0)
wom$EG <- ifelse(substr(wom$v000,1,2) =="EG", 1, 0)
wom$ET <- ifelse(substr(wom$v000,1,2) =="ET", 1, 0)
wom$GA <- ifelse(substr(wom$v000,1,2) =="GA", 1, 0)
wom$LS <- ifelse(substr(wom$v000,1,2) =="LS", 1, 0)
wom$LB <- ifelse(substr(wom$v000,1,2) =="LB", 1, 0)
wom$MA <- ifelse(substr(wom$v000,1,2) =="MA", 1, 0)
wom$MD <- ifelse(substr(wom$v000,1,2) =="MD", 1, 0)
wom$MW <- ifelse(substr(wom$v000,1,2) =="MW", 1, 0)
wom$ML <- ifelse(substr(wom$v000,1,2) =="ML", 1, 0)
wom$MZ <- ifelse(substr(wom$v000,1,2) =="MZ", 1, 0)
wom$NM <- ifelse(substr(wom$v000,1,2) =="NM", 1, 0)
wom$TG <- ifelse(substr(wom$v000,1,2) =="TG", 1, 0)
wom$RW <- ifelse(substr(wom$v000,1,2) =="RW", 1, 0)
wom$SN <- ifelse(substr(wom$v000,1,2) =="SN", 1, 0)
wom$SL <- ifelse(substr(wom$v000,1,2) =="SL", 1, 0)
wom$SZ <- ifelse(substr(wom$v000,1,2) =="SZ", 1, 0)
wom$UG <- ifelse(substr(wom$v000,1,2) =="UG", 1, 0)
wom$ZM <- ifelse(substr(wom$v000,1,2) =="ZM", 1, 0)
wom$ZW <- ifelse(substr(wom$v000,1,2) =="ZW", 1, 0)
wom$BD <- ifelse(substr(wom$v000,1,2) =="BD", 1, 0)
wom$KH <- ifelse(substr(wom$v000,1,2) =="KH", 1, 0)
wom$ID <- ifelse(substr(wom$v000,1,2) =="ID", 1, 0)
wom$NP <- ifelse(substr(wom$v000,1,2) =="NP", 1, 0)
wom$PK <- ifelse(substr(wom$v000,1,2) =="PK", 1, 0)
wom$PH <- ifelse(substr(wom$v000,1,2) =="PH", 1, 0)
wom$BO <- ifelse(substr(wom$v000,1,2) =="BO", 1, 0)
wom$CO <- ifelse(substr(wom$v000,1,2) =="CO", 1, 0)
wom$HN <- ifelse(substr(wom$v000,1,2) =="HN", 1, 0)
wom$PE <- ifelse(substr(wom$v000,1,2) =="PE", 1, 0)
wom$JO <- ifelse(substr(wom$v000,1,2) =="JO", 1, 0)

# here we assign to each woman the characteristics of her cluster

# First, initialize new objects to full length before the loop,
# rather than increasing their size within the loop. 
wom[c("density90","meaneduc","meaneduc_sp","meanmortal","meanmarriage","urban","meanelectr","meanrefri",
      "calories_pre1500_norm","calories_norm","clusternumber","dis_site","dis_site_col","dist_site_nocol",
      "country_poor","gdp_capita")] <- NA 

#then the slow loop
for (i in listc) {
wom[wom$cluster==i,"density90"] <- cl$dens90[cl$id==i]
wom[wom$cluster==i,"calories_norm"] <- cl$calories_norm[cl$id==i]
wom[wom$cluster==i,"calories_pre1500_norm"] <- cl$calories_pre1500_norm[cl$id==i]
wom[wom$cluster==i,"urban"] <- cl$urban[cl$id==i]
wom[wom$cluster==i,"country_poor"] <- cl$country_poor[cl$id==i]
wom[wom$cluster==i,"gdp_capita"] <- cl$gdp_capita[cl$id==i]

wom[wom$cluster==i,"clusternumber"] <- which(cl$id==i)
wom[wom$cluster==i,"dist_site"] <- cl$dist_site[cl$id==i]
wom[wom$cluster==i,"dist_site_col"] <- cl$dist_site_col[cl$id==i]
wom[wom$cluster==i,"dist_site_nocol"] <- cl$dist_site_nocol[cl$id==i]

wom[wom$cluster==i,"meaneduc"] <- cl$educ[cl$id==i]
wom[wom$cluster==i,"meanmortal"] <- cl$mortal[cl$id==i]
wom[wom$cluster==i,"meanmarriage"] <- cl$marriage[cl$id==i]

wom[wom$cluster==i,"meanelectr"] <- cl$electr[cl$id==i]
wom[wom$cluster==i,"meanrefri"] <- cl$refri[cl$id==i]
wom[wom$cluster==i,"meaneduc_sp"] <- cl$educ_sp[cl$id==i]
}



wom$dens90q <- wom$density90^2
wom$agesq <- wom$age^2
wom$educsq <- wom$educ^2
wom$meaneducsq <- wom$meaneduc^2
wom$urbandens90 <- log(wom$density90)*wom$urban

# age dummies
#age 15 is reference level
wom$d16=ifelse(wom$age==16,1,0)
wom$d17=ifelse(wom$age==17,1,0)
wom$d18=ifelse(wom$age==18,1,0)
wom$d19=ifelse(wom$age==19,1,0)
wom$d20=ifelse(wom$age==20,1,0)
wom$d21=ifelse(wom$age==21,1,0)
wom$d22=ifelse(wom$age==22,1,0)
wom$d23=ifelse(wom$age==23,1,0)
wom$d24=ifelse(wom$age==24,1,0)
wom$d25=ifelse(wom$age==25,1,0)
wom$d26=ifelse(wom$age==26,1,0)
wom$d27=ifelse(wom$age==27,1,0)
wom$d28=ifelse(wom$age==28,1,0)
wom$d29=ifelse(wom$age==29,1,0)
wom$d30=ifelse(wom$age==30,1,0)
wom$d31=ifelse(wom$age==31,1,0)
wom$d32=ifelse(wom$age==32,1,0)
wom$d33=ifelse(wom$age==33,1,0)
wom$d34=ifelse(wom$age==34,1,0)
wom$d35=ifelse(wom$age==35,1,0)
wom$d36=ifelse(wom$age==36,1,0)
wom$d37=ifelse(wom$age==37,1,0)
wom$d38=ifelse(wom$age==38,1,0)
wom$d39=ifelse(wom$age==39,1,0)
wom$d40=ifelse(wom$age==40,1,0)
wom$d41=ifelse(wom$age==41,1,0)
wom$d42=ifelse(wom$age==42,1,0)
wom$d43=ifelse(wom$age==43,1,0)
wom$d44=ifelse(wom$age==44,1,0)
wom$d45=ifelse(wom$age==45,1,0)
wom$d46=ifelse(wom$age==46,1,0)
wom$d47=ifelse(wom$age==47,1,0)
wom$d48=ifelse(wom$age==48,1,0)
wom$d49=ifelse(wom$age==49,1,0)



#------------------------------------------------------------
# here we generate a variable continent
# continent= 1 for africa; 2 for america; 3 for asia- south east and 4 for arabic countries

wom$continent <- ifelse( 
#wom$AO==1 | 
				wom$BJ==1 | wom$BF==1 | wom$BU==1 | wom$CM==1 | wom$CF==1 | wom$KM==1 |
				 wom$CD==1 | wom$CI==1 | wom$ET==1 | wom$GA==1 | wom$GH==1 | wom$GN==1 | wom$KE==1 |
				 wom$LS==1 | wom$LB==1 | wom$MD==1 | wom$MW==1 | wom$ML==1 | wom$MZ==1 |
				 wom$NM==1 | wom$NI==1 | wom$NG==1 | wom$RW==1 | wom$SN==1 | wom$SL==1 | 
				 wom$SZ==1 | wom$TG==1 | wom$TZ==1 | wom$UG==1 | wom$ZM==1 | wom$ZW==1,1,
                     ifelse( wom$BO==1 | wom$CO==1 | wom$HN==1 | wom$PE==1,2,
                     ifelse( wom$BD==1 | wom$KH==1 | wom$ID==1 | wom$NP==1 | wom$PK==1 | wom$PH==1,3,
                     ifelse( wom$MA==1 | wom$EG==1 | wom$JO==1,4,0))))

summary(wom$continent) # min should be 1 




